@@ -104,7 +104,6 @@ class RescissionWorkflow:
 
     def update(
         self,
-        rescission_uuid: str,
         process_code: int = None,
         process_status: int = None,
         start_date: datetime = None,
@@ -119,7 +118,7 @@ class RescissionWorkflow:
         target_admission_date: datetime = None,
         code_reason_rescission: int = None,
         activity_name: str = None,
-        recision_time: datetime = None,
+        rescission_time: datetime = None,
         face_to_face_communication: str = None,
         email_corp_witness_1: str = None,
         email_corp_witness_2: str = None,
@@ -137,10 +136,9 @@ class RescissionWorkflow:
         servicenow_sys_id: str = None,
         servicenow_ticket_number: str = None,
     ):
-        return self.http.put(
-            url=f"{self.severino_api_url}{self.path}/{rescission_uuid}/",
+        return self.http.patch(
+            url=f"{self.severino_api_url}{self.path}/{process_code}/",
             data={
-                "process_code": process_code,
                 "process_status": process_status,
                 "start_date": start_date.strftime("%Y-%m-%d") if start_date else None,
                 "completion_date": completion_date.strftime("%Y-%m-%d")
@@ -162,8 +160,8 @@ class RescissionWorkflow:
                 else None,
                 "code_reason_rescission": code_reason_rescission,
                 "activity_name": activity_name,
-                "recision_time": recision_time.strftime("%Y-%m-%d %H:%M:%S")
-                if recision_time
+                "rescission_time": rescission_time.strftime("%Y-%m-%d %H:%M:%S")
+                if rescission_time
                 else None,
                 "face_to_face_communication": face_to_face_communication,
                 "email_corp_witness_1": email_corp_witness_1,
@@ -184,12 +182,21 @@ class RescissionWorkflow:
             },
         )
 
+    def partial_update(
+        self,
+        process_code: int,
+        data: dict,
+    ):
+        return self.http.patch(
+            url=f"{self.severino_api_url}{self.path}/{process_code}/", data=data
+        )
+
     def delete(self, rescission_uuid):
         return self.http.delete(
             url=f"{self.severino_api_url}{self.path}/{rescission_uuid}/"
         )
 
-    def change_status(self, rescission_uuid: str, sys_status: str):
+    def change_status(self, process_code: str, sys_status: str):
         status_choices = [
             "waiting",
             "future_dismissal",
@@ -208,6 +215,6 @@ class RescissionWorkflow:
         data = {"sys_status": sys_status}
 
         return self.http.patch(
-            url=f"{self.severino_api_url}{self.path}/{rescission_uuid}/",
+            url=f"{self.severino_api_url}{self.path}/{process_code}/",
             data=data,
         )
